Module config

Module config 

Structs

ConfigFile
Represents the parsed TOML config file. All fields optional.
ConnectionConfig
LaunchConfig
OutputConfig
ResolvedConfig
Fully resolved configuration with all defaults filled in.
ResolvedConnection
ResolvedLaunch
ResolvedOutput
ResolvedTabs
TabsConfig

Enums

ConfigError

Functions

default_init_path
Default path for config init: <config_dir>/chrome-cli/config.toml.
find_config_file
Find the first config file that exists, checking locations in priority order.
find_config_file_with
Testable variant of find_config_file that accepts an explicit env value.
init_config
Create a default config file at the given path (or the default XDG path).
init_config_to
Testable variant of init_config that writes to an explicit path.
load_config
Load and parse a config file. Returns the file path (if found) and the parsed config.
load_config_from
Load and parse a config file from a specific path.
parse_config
Parse TOML content into a ConfigFile.
resolve_config
Resolve a config file into a fully-populated ResolvedConfig with all defaults.