init_config

Function init_config 

pub fn init_config(target_path: Option<&Path>) -> Result<PathBuf, ConfigError>
Create a default config file at the given path (or the default XDG path).

Errors

  • ConfigError::AlreadyExists if the file already exists
  • ConfigError::Io on I/O failure
  • ConfigError::NoConfigDir if no target path and platform config dir unknown