pub fn load_config_from(path: &Path) -> ConfigFileExpand description
Load and parse a config file from a specific path.
On parse errors, prints a warning to stderr and returns ConfigFile::default().
pub fn load_config_from(path: &Path) -> ConfigFileLoad and parse a config file from a specific path.
On parse errors, prints a warning to stderr and returns ConfigFile::default().