Module connection

Module connection 

Structs

ManagedSession
A CDP session wrapper that tracks which domains have been enabled, ensuring each domain is only enabled once (lazy domain enabling).
ResolvedConnection
Resolved connection info ready for use by a command.

Constants

DEFAULT_CDP_PORT
Default Chrome DevTools Protocol port.

Functions

extract_port_from_ws_url
Extract port from a WebSocket URL like ws://host:port/path.
health_check
Health-check a connection by querying /json/version.
resolve_connection
Resolve a Chrome connection using the priority chain:
resolve_target
Resolve the target tab from the --tab option by querying Chrome for targets.
select_target
Select a target from a list based on the --tab option.