command

Function command 

pub fn command() -> Command
Returns the clap Command definition for man page and completion generation.

This is used by the xtask binary to generate man pages without depending on the binary crate directly.