Structs
- Browser
Version - Browser version information returned by
/json/version. - Chrome
Process - A handle to a running Chrome process.
- Launch
Config - Configuration for launching a Chrome process.
- Target
Info - Information about a single debuggable target (tab, service worker, etc.).
Enums
- Channel
- Chrome release channel.
- Chrome
Error - Errors that can occur during Chrome discovery and launch.
Functions
- activate_
target - Activate a target via Chrome’s
/json/activate/{id}endpoint. - default_
user_ data_ dir - Returns the default Chrome user data directory for the current platform.
- discover_
chrome - Attempt to discover a running Chrome instance.
- find_
available_ port - Find an available TCP port on localhost.
- find_
chrome_ executable - Find a Chrome executable for the given release channel.
- launch_
chrome - Launch a Chrome process with the given configuration.
- query_
targets - Query Chrome’s
/json/listendpoint for debuggable targets. - query_
version - Query Chrome’s
/json/versionendpoint. - read_
devtools_ active_ port - Read the
DevToolsActivePortfile from the default user data directory. - read_
devtools_ active_ port_ from - Read the
DevToolsActivePortfile from a specific directory.