pub fn init_config(target_path: Option<&Path>) -> Result<PathBuf, ConfigError>Expand description
Create a default config file at the given path (or the default XDG path).
Errors
ConfigError::AlreadyExistsif the file already existsConfigError::Ioon I/O failureConfigError::NoConfigDirif no target path and platform config dir unknown