pub fn command() -> Command
Returns the clap Command definition for man page and completion generation.
Command
This is used by the xtask binary to generate man pages without depending on the binary crate directly.